@@ -149,8 +149,8 @@ struct _GcalWindow
 
   NewEventData        *event_creation_data;
 
-  GcalEvent           *event_to_delete;
-  ECalObjModType       event_to_delete_mod;
+  GcalEvent             *event_to_delete;
+  GcalRecurrenceModType  event_to_delete_mod;
 
   /* calendar management */
   GtkWidget           *calendar_popover;
@@ -522,7 +522,6 @@ calendar_listbox_sort_func (GtkListBoxRow *row1,
 static void
 load_geometry (GcalWindow *window)
 {
-  GcalApplication *app;
   GSettings *settings;
   GVariant *variant;
   gboolean maximized;
@@ -532,8 +531,7 @@ load_geometry (GcalWindow *window)
 
   GCAL_ENTRY;
 
-  app = GCAL_APPLICATION (gtk_window_get_application (GTK_WINDOW (window)));
-  settings = gcal_application_get_settings (app);
+  settings = gcal_manager_get_settings (window->manager);
 
   /* load window settings: size */
   variant = g_settings_get_value (settings,
@@ -576,7 +574,6 @@ save_geometry (gpointer user_data)
   GtkWindow *self;
   GdkWindow *win;
   GdkWindowState state;
-  GcalApplication *app;
   GSettings *settings;
   gboolean maximized;
   GVariant *variant;
@@ -589,10 +586,7 @@ save_geometry (gpointer user_data)
   window = GCAL_WINDOW (self);
   win = gtk_widget_get_window (GTK_WIDGET (self));
   state = gdk_window_get_state (win);
-
-
-  app = GCAL_APPLICATION (gtk_window_get_application (self));
-  settings = gcal_application_get_settings (app);
+  settings = gcal_manager_get_settings (window->manager);
 
   /* save window's state */
   maximized = state & GDK_WINDOW_STATE_MAXIMIZED;
@@ -1081,12 +1075,12 @@ edit_dialog_closed (GtkDialog *dialog,
                     gint       response,
                     gpointer   user_data)
 {
+  GcalRecurrenceModType mod;
   GcalWindow *window;
   GcalEditDialog *edit_dialog;
   GcalEvent *event;
   GcalView *view;
   GList *widgets;
-  ECalObjModType mod;
   ESource *source;
 
   GCAL_ENTRY;
@@ -1095,7 +1089,7 @@ edit_dialog_closed (GtkDialog *dialog,
   edit_dialog = GCAL_EDIT_DIALOG (dialog);
   event = gcal_edit_dialog_get_event (edit_dialog);
   view = GCAL_VIEW (window->views[window->active_view]);
-  mod = E_CAL_OBJ_MOD_THIS;
+  mod = GCAL_RECURRENCE_MOD_THIS_ONLY;
   source = gcal_event_get_source (event);
 
   if (!gcal_edit_dialog_get_recurrence_changed (edit_dialog) &&
@@ -1145,7 +1139,7 @@ edit_dialog_closed (GtkDialog *dialog,
       window->event_to_delete_mod = mod;
 
       /* hide widget of the event */
-      widgets = gcal_view_get_children_by_uuid (view, gcal_event_get_uid (event));
+      widgets = gcal_view_get_children_by_uuid (view, mod, gcal_event_get_uid (event));
 
       g_list_foreach (widgets, (GFunc) gtk_widget_hide, NULL);
       g_list_free (widgets);
@@ -1242,6 +1236,7 @@ undo_remove_action (GtkButton *button,
 
   window = GCAL_WINDOW (user_data);
   widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (window->views[window->active_view]),
+                                            window->event_to_delete_mod,
                                             gcal_event_get_uid (window->event_to_delete));
 
   /* Show the hidden to-be-deleted events */
@@ -1263,7 +1258,9 @@ schedule_open_edit_dialog_by_uuid (OpenEditDialogData *edit_dialog_data)
   GList *widgets;
 
   window = edit_dialog_data->window;
-  widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (window->month_view), edit_dialog_data->uuid);
+  widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (window->month_view),
+                                            GCAL_RECURRENCE_MOD_THIS_ONLY,
+                                            edit_dialog_data->uuid);
   if (widgets != NULL)
     {
       window->open_edit_dialog_timeout_id = 0;
@@ -1286,23 +1283,9 @@ gcal_window_finalize (GObject *object)
 
   GCAL_ENTRY;
 
-  if (window->save_geometry_timeout_id > 0)
-    {
-      g_source_remove (window->save_geometry_timeout_id);
-      window->save_geometry_timeout_id = 0;
-    }
-
-  if (window->open_edit_dialog_timeout_id > 0)
-    {
-      g_source_remove (window->open_edit_dialog_timeout_id);
-      window->open_edit_dialog_timeout_id = 0;
-    }
-
-  if (window->refresh_timeout_id > 0)
-    {
-      g_source_remove (window->refresh_timeout_id);
-      window->refresh_timeout_id = 0;
-    }
+  gcal_clear_timeout (&window->save_geometry_timeout_id);
+  gcal_clear_timeout (&window->open_edit_dialog_timeout_id);
+  gcal_clear_timeout (&window->refresh_timeout_id);
 
   /* If we have a queued event to delete, remove it now */
   if (window->event_to_delete)
@@ -1311,7 +1294,7 @@ gcal_window_finalize (GObject *object)
       g_clear_object (&window->event_to_delete);
     }
 
-  if (window->event_creation_data != NULL)
+  if (window->event_creation_data)
     {
       g_clear_pointer (&window->event_creation_data->start_date, g_date_time_unref);
       g_clear_pointer (&window->event_creation_data->end_date, g_date_time_unref);
@@ -1321,7 +1304,7 @@ gcal_window_finalize (GObject *object)
   g_clear_object (&window->manager);
   g_clear_object (&window->views_switcher);
 
-  g_free (window->active_date);
+  g_clear_pointer (&window->active_date, g_free);
 
   G_OBJECT_CLASS (gcal_window_parent_class)->finalize (object);
 
@@ -1358,6 +1341,11 @@ gcal_window_set_property (GObject      *object,
     case PROP_MANAGER:
       if (g_set_object (&self->manager, g_value_get_object (value)))
         {
+          g_settings_bind (gcal_manager_get_settings (self->manager),
+                           "active-view",
+                           self,
+                           "active-view",
+                           G_SETTINGS_BIND_SET | G_SETTINGS_BIND_GET);
 
           if (!gcal_manager_get_loading (self->manager))
             {
@@ -1376,12 +1364,6 @@ gcal_window_set_property (GObject      *object,
           g_signal_connect_swapped (self->manager, "source-enabled", G_CALLBACK (source_enabled), object);
           g_signal_connect_swapped (self->manager, "source-changed", G_CALLBACK (source_changed), object);
 
-          gcal_edit_dialog_set_manager (GCAL_EDIT_DIALOG (self->edit_dialog), self->manager);
-          gcal_week_view_set_manager (GCAL_WEEK_VIEW (self->week_view), self->manager);
-          gcal_month_view_set_manager (GCAL_MONTH_VIEW (self->month_view), self->manager);
-          gcal_year_view_set_manager (GCAL_YEAR_VIEW (self->year_view), self->manager);
-          gcal_quick_add_popover_set_manager (GCAL_QUICK_ADD_POPOVER (self->quick_add_popover), self->manager);
-          gcal_source_dialog_set_manager (GCAL_SOURCE_DIALOG (self->source_dialog), self->manager);
           gcal_search_view_connect (GCAL_SEARCH_VIEW (self->search_view), self->manager);
 
           g_object_notify (object, "manager");
@@ -1488,7 +1470,6 @@ gcal_window_class_init(GcalWindowClass *klass)
   widget_class = GTK_WIDGET_CLASS (klass);
   widget_class->configure_event = gcal_window_configure_event;
   widget_class->window_state_event = gcal_window_state_event;
-  gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/calendar/window.ui");
 
   g_object_class_install_property (
       object_class,
@@ -1505,7 +1486,7 @@ gcal_window_class_init(GcalWindowClass *klass)
       PROP_MANAGER,
       g_param_spec_object ("manager",
                            "The manager object",
-                           "A weak reference to the app manager object",
+                           "The manager object",
                            GCAL_TYPE_MANAGER,
                            G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
 
@@ -1527,6 +1508,8 @@ gcal_window_class_init(GcalWindowClass *klass)
                             FALSE,
                             G_PARAM_READWRITE));
 
+  gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/calendar/window.ui");
+
   /* widgets */
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, edit_dialog);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, header_bar);
@@ -1656,6 +1639,17 @@ gcal_window_init (GcalWindow *self)
   self->active_date = g_new0 (icaltimetype, 1);
   self->rtl = gtk_widget_get_direction (GTK_WIDGET (self)) == GTK_TEXT_DIR_RTL;
 
+  /*
+   * FIXME: this is a hack around the issue that happens when trying to bind
+   * there properties using the GtkBuilder .ui file.
+   */
+  g_object_bind_property (self, "manager", self->edit_dialog, "manager", G_BINDING_DEFAULT);
+  g_object_bind_property (self, "manager", self->source_dialog, "manager", G_BINDING_DEFAULT);
+  g_object_bind_property (self, "manager", self->week_view, "manager", G_BINDING_DEFAULT);
+  g_object_bind_property (self, "manager", self->month_view, "manager", G_BINDING_DEFAULT);
+  g_object_bind_property (self, "manager", self->year_view, "manager", G_BINDING_DEFAULT);
+  g_object_bind_property (self, "manager", self->quick_add_popover, "manager", G_BINDING_DEFAULT);
+
   /* setup accels */
   app = g_application_get_default ();
 
@@ -1672,20 +1666,17 @@ gcal_window_init (GcalWindow *self)
 
 /* Public API */
 /**
- * gcal_window_new_with_view_and_date:
+ * gcal_window_new_with_date:
  * @app: a #GcalApplication
- * @view_type: a #GcalWindowViewType
  * @date: the active date
  *
- * Creates a #GcalWindow, positions it at @date and shows
- * @view_type view by default.
+ * Creates a #GcalWindow, positions it at @date.
  *
  * Returns: (transfer full): a #GcalWindow
  */
 GtkWidget*
-gcal_window_new_with_view_and_date (GcalApplication    *app,
-                                    GcalWindowViewType  view_type,
-                                    icaltimetype       *date)
+gcal_window_new_with_date (GcalApplication *app,
+                           icaltimetype    *date)
 {
   GcalManager *manager;
   GcalWindow *win;
@@ -1700,9 +1691,6 @@ gcal_window_new_with_view_and_date (GcalApplication    *app,
   /* loading size */
   load_geometry (win);
 
-  if (view_type == GCAL_WINDOW_VIEW_DAY)
-    view_changed (NULL, NULL, win);
-
   return GTK_WIDGET (win);
 }
 
@@ -1798,7 +1786,9 @@ gcal_window_open_event_by_uuid (GcalWindow  *self,
   /* XXX: show events on month view */
   gtk_stack_set_visible_child (GTK_STACK (self->views_stack), self->month_view);
 
-  widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (self->month_view), uuid);
+  widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (self->month_view),
+                                            GCAL_RECURRENCE_MOD_THIS_ONLY,
+                                            uuid);
 
   if (widgets)
     {
